@@ -1,8 +1,9 @@
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
-use cosmwasm_std::Uint128;
+use cosmwasm_std::{Addr, Binary, Uint128};
 
+use crate::logo::LogoInfo;
 use cw0::Expiration;
 
 #[derive(Serialize, Deserialize, Clone, PartialEq, JsonSchema, Debug)]
@@ -19,9 +20,19 @@ pub enum Cw20QueryMsg {
     /// Return type: AllowanceResponse.
     Allowance { owner: String, spender: String },
     /// Only with "mintable" extension.
-    /// Returns who can mint and how much.
+    /// Returns who can mint and the hard cap on maximum tokens after minting.
     /// Return type: MinterResponse.
     Minter {},
+    /// Only with "marketing" extension
+    /// Returns more metadata on the contract to display in the client:
+    /// - description, logo, project url, etc.
+    /// Return type: MarketingInfoResponse.
+    MarketingInfo {},
+    /// Only with "marketing" extension
+    /// Downloads the embedded logo data (if stored on chain). Errors if no logo data stored for
+    /// this contract.
+    /// Return type: DownloadLogoResponse.
+    DownloadLogo {},
     /// Only with "enumerable" extension (and "allowances")
     /// Returns all allowances this owner has approved. Supports pagination.
     /// Return type: AllAllowancesResponse.
@@ -61,10 +72,32 @@ pub struct AllowanceResponse {
 #[derive(Serialize, Deserialize, Clone, PartialEq, JsonSchema, Debug)]
 pub struct MinterResponse {
     pub minter: String,
-    /// cap is how many more tokens can be issued by the minter
+    /// cap is a hard cap on total supply that can be achieved by minting.
+    /// Note that this refers to total_supply.
+    /// If None, there is unlimited cap.
     pub cap: Option<Uint128>,
 }
 
+#[derive(Serialize, Deserialize, Clone, PartialEq, JsonSchema, Debug, Default)]
+pub struct MarketingInfoResponse {
+    /// A URL pointing to the project behind this token.
+    pub project: Option<String>,
+    /// A longer description of the token and it's utility. Designed for tooltips or such
+    pub description: Option<String>,
+    /// A link to the logo, or a comment there is an on-chain logo stored
+    pub logo: Option<LogoInfo>,
+    /// The address (if any) who can update this data structure
+    pub marketing: Option<Addr>,
+}
+
+/// When we download an embedded logo, we get this response type.
+/// We expect a SPA to be able to accept this info and display it.
+#[derive(Serialize, Deserialize, Clone, PartialEq, JsonSchema, Debug)]
+pub struct DownloadLogoResponse {
+    pub mime_type: String,
+    pub data: Binary,
+}
+
 #[derive(Serialize, Deserialize, Clone, PartialEq, JsonSchema, Debug)]
 pub struct AllowanceInfo {
     pub spender: String,
